@@ -2,3 +2,5 @@
 # User: 駿清清 
 # Date: 01/11/2022 
 # Time: 20:53
+def main():
+    return "hello"
\ No newline at end of file
